Author: cgutman
Date: Tue Jun 23 16:41:14 2009
New Revision: 41583
URL:
http://svn.reactos.org/svn/reactos?rev=41583&view=rev
Log:
- Fix adapter failure when a network address is not specified in the registry
- As a bonus, it also fixes OID_802_3_PERMANENT_ADDRESS
Modified:
trunk/reactos/drivers/network/dd/ne2000/ne2000/8390.c
Modified: trunk/reactos/drivers/network/dd/ne2000/ne2000/8390.c
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/drivers/network/dd/ne2000/…
==============================================================================
--- trunk/reactos/drivers/network/dd/ne2000/ne2000/8390.c [iso-8859-1] (original)
+++ trunk/reactos/drivers/network/dd/ne2000/ne2000/8390.c [iso-8859-1] Tue Jun 23 16:41:14
2009
@@ -266,9 +266,9 @@
for (i = 0; i < 16; i++)
Adapter->SAPROM[i] = Buffer[i * 2];
/* Copy the station address */
NdisMoveMemory(
- (PVOID)&Adapter->StationAddress,
+ (PVOID)&Adapter->PermanentAddress,
(PVOID)&Adapter->SAPROM,
DRIVER_LENGTH_OF_ADDRESS);
@@ -266,9 +266,9 @@
for (i = 0; i < 16; i++)
Adapter->SAPROM[i] = Buffer[i * 2];
- /* Copy the station address */
+ /* Copy the permanent address */
NdisMoveMemory(